/* lilydirectives.h
 *
 *
 * (c) 2000-2005 Adam Tee <eenajt@electeng.leeds.ac.uk>
 *
 */

#ifndef LILYDIRECTIVE_H

#define LILYDIRECTIVE_H

#include <denemo/denemo.h>

void insertdirective(GtkWidget *widget, gpointer data);
void lily_directive(GtkAction *action, gpointer callback_data);


#endif
